@@ -4,8 +4,8 @@ from WebKit import *
 
 class TestDOMHTMLFrameElement (TestCase):
     def testMethods(self):
-        self.failUnlessResultIsBOOL(DOMHTMLFrameElement.noResize)
-        self.failUnlessArgIsBOOL(DOMHTMLFrameElement.setNoResize_, 0)
+        self.assertResultIsBOOL(DOMHTMLFrameElement.noResize)
+        self.assertArgIsBOOL(DOMHTMLFrameElement.setNoResize_, 0)
 
 if __name__ == "__main__":
     main()
